@@ -23,6 +23,9 @@ FAILEDOPERATION_APPLICATIONCREATEESATUHERROR = 'FailedOperation.ApplicationCreat
 # 应用查询失败。
 FAILEDOPERATION_APPLICATIONQUERYFAILED = 'FailedOperation.ApplicationQueryFailed'
 
+# TSF应用性能管理调用tsf-dcfg模块失败
+FAILEDOPERATION_CALLTSFDCFGFAILED = 'FailedOperation.CallTsfDcfgFailed'
+
 # TSF云API请求调用失败。
 FAILEDOPERATION_CLOUDAPIPROXYERROR = 'FailedOperation.CloudApiProxyError'
 
@@ -89,6 +92,12 @@ FAILEDOPERATION_CONTAINERGROUPKUBERNETESCONNECTERROR = 'FailedOperation.Containe
 # 健康检查配置失败。
 FAILEDOPERATION_CVMCAEMASTERHEALTHCHECKCONFIGERROR = 'FailedOperation.CvmCaeMasterHealthCheckConfigError'
 
+# TSF暂时不能响应请求。
+FAILEDOPERATION_DISPATCHCOMMONERROR = 'FailedOperation.DispatchCommonError'
+
+# 寻找独占配置中心相关指标异常
+FAILEDOPERATION_FINDMETRICSEXCLUSIVEERROR = 'FailedOperation.FindMetricsExclusiveError'
+
 # 远端访问错误: %s。
 FAILEDOPERATION_GATEWAYREMOTECALLERROR = 'FailedOperation.GatewayRemoteCallError'
 
@@ -98,6 +107,12 @@ FAILEDOPERATION_GROUPEXISTS = 'FailedOperation.GroupExists'
 # 部署组查询失败。
 FAILEDOPERATION_GROUPQUERYFAILD = 'FailedOperation.GroupQueryFaild'
 
+# 镜像仓库已关联至部署组，请移除后重试
+FAILEDOPERATION_IMAGEVALIDATEISUSED = 'FailedOperation.ImageValidateIsUsed'
+
+# 禁止直接删除应用镜像仓库, 需要先删除下面的镜像tag
+FAILEDOPERATION_IMAGEREPOREJECTDELERROR = 'FailedOperation.ImagerepoRejectDelError'
+
 # tcr仓库绑定失败。
 FAILEDOPERATION_IMAGEREPOTCRBINDERROR = 'FailedOperation.ImagerepoTcrBindError'
 
@@ -239,6 +254,9 @@ FAILEDOPERATION_TSFAPMCALLTSFMSFAILED = 'FailedOperation.TsfApmCallTsfMsFailed'
 # TSF应用性能管理CTSDB客户端调用失败。
 FAILEDOPERATION_TSFAPMCTSDBCLIENTREQUESTERROR = 'FailedOperation.TsfApmCtsdbClientRequestError'
 
+# TSF应用性能管理ES客户端调用失败。
+FAILEDOPERATION_TSFAPMESCLIENTREQUESTERROR = 'FailedOperation.TsfApmEsClientRequestError'
+
 # TSF应用性能管理内部异常, 请稍后重试。
 FAILEDOPERATION_TSFAPMINTERNALERROR = 'FailedOperation.TsfApmInternalError'
 
@@ -545,7 +563,7 @@ INVALIDPARAMETER_UPPERDELETELIMIT = 'InvalidParameter.UpperDeleteLimit'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
-# 应用描述不能大于200组字符。
+# 应用描述不能大于200个字符。
 INVALIDPARAMETERVALUE_APPLICATIONDESCLENGTH = 'InvalidParameterValue.ApplicationDescLength'
 
 # 无效的微服务类型。
@@ -908,7 +926,7 @@ INVALIDPARAMETERVALUE_LANERULETAGVALUETOTALTOOLONG = 'InvalidParameterValue.Lane
 # 集群已关联该命名空间。
 INVALIDPARAMETERVALUE_NAMESPACEALREADYBINDCLUSTER = 'InvalidParameterValue.NamespaceAlreadyBindCluster'
 
-# 命名空间描格式不正确。
+# 命名空间描述格式不正确。
 INVALIDPARAMETERVALUE_NAMESPACEDESCINVALID = 'InvalidParameterValue.NamespaceDescInvalid'
 
 # 命名空间名称已存在，请更换其他名称。
@@ -1031,6 +1049,9 @@ MISSINGPARAMETER_INSTANCEIMPORTMODENULL = 'MissingParameter.InstanceImportModeNu
 # 命名空间ID不能为空。
 MISSINGPARAMETER_NAMESPACEIDREQUIRED = 'MissingParameter.NamespaceIdRequired'
 
+# 命名空间名称未填写。
+MISSINGPARAMETER_NAMESPACENAMEREQUIRED = 'MissingParameter.NamespaceNameRequired'
+
 # %s缺失。
 MISSINGPARAMETER_REQUIREDPARAMETERMISSING = 'MissingParameter.RequiredParameterMissing'
 
